@@ -1,5 +1,5 @@
 package XML::Grammar::Fortune::Synd;
-$XML::Grammar::Fortune::Synd::VERSION = '0.0214';
+$XML::Grammar::Fortune::Synd::VERSION = '0.0215';
 use warnings;
 use strict;
 
@@ -8,7 +8,7 @@ use 5.008;
 
 use parent 'Class::Accessor';
 
-use YAML::XS (qw( DumpFile LoadFile ));
+use YAML::XS        (qw( DumpFile LoadFile ));
 use Heap::Elem::Ref (qw(RefElem));
 use Heap::Binary;
 use XML::Feed;
@@ -18,26 +18,28 @@ use XML::Grammar::Fortune::Synd::Heap::Elem;
 
 use File::Spec;
 
-__PACKAGE__->mk_accessors(qw(
+__PACKAGE__->mk_accessors(
+    qw(
         _xml_parser
         _file_doms
         _date_formatter
         xml_files
         url_callback
         _file_processors
-    ));
+        )
+);
 
 
 sub new
 {
-    my ($class, $args) = @_;
+    my ( $class, $args ) = @_;
 
     my $self = $class->SUPER::new($args);
 
-    $self->_xml_parser(XML::LibXML->new());
-    $self->_date_formatter(DateTime::Format::W3CDTF->new());
-    $self->_file_doms(+{});
-    $self->_file_processors(+{});
+    $self->_xml_parser( XML::LibXML->new() );
+    $self->_date_formatter( DateTime::Format::W3CDTF->new() );
+    $self->_file_doms( +{} );
+    $self->_file_processors( +{} );
 
     return $self;
 }
@@ -45,24 +47,23 @@ sub new
 
 sub calc_feeds
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     my $scripts_hash_filename = $args->{'yaml_persistence_file'};
-    my $scripts_hash_fn_out =   $args->{'yaml_persistence_file_out'};
-    my $xmls_dir = $args->{xmls_dir};
-
+    my $scripts_hash_fn_out   = $args->{'yaml_persistence_file_out'};
+    my $xmls_dir              = $args->{xmls_dir};
 
     my $persistent_data;
-    if (-e $scripts_hash_filename)
+    if ( -e $scripts_hash_filename )
     {
-        $persistent_data = LoadFile ($scripts_hash_filename);
+        $persistent_data = LoadFile($scripts_hash_filename);
     }
     else
     {
         $persistent_data = +{};
     }
 
-    if (!exists($persistent_data->{'files'}))
+    if ( !exists( $persistent_data->{'files'} ) )
     {
         $persistent_data->{'files'} = +{};
     }
@@ -75,17 +76,16 @@ sub calc_feeds
 
     my $ids_limit = 20;
 
-    foreach my $file (@{$self->xml_files()})
+    foreach my $file ( @{ $self->xml_files() } )
     {
         my $xml = $self->_xml_parser->parse_file(
-            File::Spec->catfile($xmls_dir, $file)
-        );
+            File::Spec->catfile( $xmls_dir, $file ) );
 
         $self->_file_doms->{$file} = $xml;
 
         my @fortune_elems = $xml->findnodes("//fortune");
 
-        my @ids = (map { $_->getAttribute("id") } @fortune_elems);
+        my @ids = ( map { $_->getAttribute("id") } @fortune_elems );
 
         my $id_count = 1;
 
@@ -93,24 +93,23 @@ sub calc_feeds
         # so we won't have globally duplicate IDs.
         {
             my $hash_ref = $scripts_hash->{$file};
-            my %ids_map = (map { $_ => 1 } @ids);
+            my %ids_map  = ( map { $_ => 1 } @ids );
 
-            foreach my $id (keys(%$hash_ref))
+            foreach my $id ( keys(%$hash_ref) )
             {
-                if (! exists($ids_map{$id}))
+                if ( !exists( $ids_map{$id} ) )
                 {
-                    delete ($hash_ref->{$id});
+                    delete( $hash_ref->{$id} );
                 }
             }
         }
 
-        IDS_LOOP:
+    IDS_LOOP:
         foreach my $id (@ids)
         {
-            if (! exists($scripts_hash->{$file}->{$id}))
+            if ( !exists( $scripts_hash->{$file}->{$id} ) )
             {
-                $scripts_hash->{$file}->{$id} =
-                {
+                $scripts_hash->{$file}->{$id} = {
                     'date' => $self->_date_formatter->format_datetime(
                         DateTime->now(),
                     ),
@@ -126,15 +125,15 @@ sub calc_feeds
                     XML::Grammar::Fortune::Synd::Heap::Elem->new(
                         {
                             date => $date,
-                            idx => $id_count,
-                            id => $id,
+                            idx  => $id_count,
+                            id   => $id,
                             file => $file,
                         }
                     )
                 )
             );
 
-            if (++$ids_heap_count > $ids_limit)
+            if ( ++$ids_heap_count > $ids_limit )
             {
                 $ids_heap->extract_top();
                 $ids_heap_count--;
@@ -149,23 +148,23 @@ sub calc_feeds
     my @recent_ids = ();
 
     # TODO : Should we reverse this?
-    while (defined(my $id_obj = $ids_heap->extract_top()))
+    while ( defined( my $id_obj = $ids_heap->extract_top() ) )
     {
         push @recent_ids, $id_obj;
     }
-    DumpFile($scripts_hash_fn_out, $persistent_data);
+    DumpFile( $scripts_hash_fn_out, $persistent_data );
 
     my @feed_formats = (qw(Atom RSS));
 
-    my %feeds = (map { $_ => XML::Feed->new($_), } @feed_formats);
+    my %feeds = ( map { $_ => XML::Feed->new($_), } @feed_formats );
 
     # First set some global parameters
-    foreach my $feed (values(%feeds))
+    foreach my $feed ( values(%feeds) )
     {
-        $feed->title($args->{feed_params}->{'title'});
-        $feed->link($args->{feed_params}->{'link'});
-        $feed->tagline($args->{feed_params}->{'tagline'});
-        $feed->author($args->{feed_params}->{'author'});
+        $feed->title( $args->{feed_params}->{'title'} );
+        $feed->link( $args->{feed_params}->{'link'} );
+        $feed->tagline( $args->{feed_params}->{'tagline'} );
+        $feed->author( $args->{feed_params}->{'author'} );
 
         my $self_link = $args->{feed_params}->{'atom_self_link'};
         $feed->self_link($self_link);
@@ -175,127 +174,132 @@ sub calc_feeds
     # Now fill the XML-Feed object:
     {
 
-        foreach my $id_obj (map { $_->val() } @recent_ids)
+        foreach my $id_obj ( map { $_->val() } @recent_ids )
         {
             my $file_dom =
-                $self->_file_doms()->{$id_obj->file()};
+                $self->_file_doms()->{ $id_obj->file() };
 
             my ($fortune_dom) =
-                $file_dom->findnodes("descendant::fortune[\@id='". $id_obj->id() . "']");
+                $file_dom->findnodes(
+                "descendant::fortune[\@id='" . $id_obj->id() . "']" );
 
-            my %entries = (map { $_ => XML::Feed::Entry->new($_) } @feed_formats);
+            my %entries =
+                ( map { $_ => XML::Feed::Entry->new($_) } @feed_formats );
 
-            my $title = $fortune_dom->findnodes("meta/title")->get_node(0)->textContent();
+            my $title = $fortune_dom->findnodes("meta/title")->get_node(0)
+                ->textContent();
 
             my $on_entries = sub {
 
                 my ($callback) = @_;
 
-                foreach my $entry (values(%entries))
+                foreach my $entry ( values(%entries) )
                 {
                     $callback->($entry);
                 }
             };
 
-            $on_entries->(sub {
-                my $entry = shift;
+            $on_entries->(
+                sub {
+                    my $entry = shift;
 
-                $entry->title($title);
-                $entry->summary($title);
-            });
+                    $entry->title($title);
+                    $entry->summary($title);
+                }
+            );
 
-            my $url =
-                $self->url_callback()->(
-                    $self,
-                    {
-                        id_obj => $id_obj,
-                    }
-                );
+            my $url = $self->url_callback()->(
+                $self,
+                {
+                    id_obj => $id_obj,
+                }
+            );
 
-            $on_entries->(sub {
-                my $entry = shift;
+            $on_entries->(
+                sub {
+                    my $entry = shift;
 
-                $entry->link( $url );
+                    $entry->link($url);
 
-                $entry->id($url);
+                    $entry->id($url);
 
-                $entry->issued($id_obj->date());
-            });
+                    $entry->issued( $id_obj->date() );
+                }
+            );
 
             {
-                $self->_file_processors()->{$id_obj->file()} ||=
+                $self->_file_processors()->{ $id_obj->file() } ||=
                     XML::Grammar::Fortune->new(
-                        {
-                            mode => "convert_to_html",
-                            output_mode => "string",
-                        }
+                    {
+                        mode        => "convert_to_html",
+                        output_mode => "string",
+                    }
                     );
 
                 my $file_processor =
-                    $self->_file_processors()->{$id_obj->file()};
+                    $self->_file_processors()->{ $id_obj->file() };
 
                 my $content = "";
 
                 $file_processor->run(
                     {
-                        xslt_params =>
-                        {
+                        xslt_params => {
                             'fortune.id' => "'" . $id_obj->id() . "'",
                         },
                         output => \$content,
-                        input => File::Spec->catfile($xmls_dir, $id_obj->file()),
+                        input  =>
+                            File::Spec->catfile( $xmls_dir, $id_obj->file() ),
                     }
                 );
 
                 $content =~ s{\A.*?<body>}{}ms;
                 $content =~ s{</body>.*\z}{}ms;
 
-                $on_entries->(sub {
-                    my $entry = shift;
+                $on_entries->(
+                    sub {
+                        my $entry = shift;
 
-                    $entry->content(
-                        XML::Feed::Content->new(
-                            {
-                                type => "text/html",
-                                body => $content,
-                            },
-                        )
-                    );
+                        $entry->content(
+                            XML::Feed::Content->new(
+                                {
+                                    type => "text/html",
+                                    body => $content,
+                                },
+                            )
+                        );
 
-                });
+                    }
+                );
             }
 
             foreach my $format (@feed_formats)
             {
-                $feeds{$format}->add_entry($entries{$format});
+                $feeds{$format}->add_entry( $entries{$format} );
             }
         }
     }
 
-    $feeds{"RSS"}->self_link($args->{feed_params}->{'rss_self_link'});
+    $feeds{"RSS"}->self_link( $args->{feed_params}->{'rss_self_link'} );
 
     {
-        my $num_entries = scalar (() = $feeds{'RSS'}->entries());
-        if ($num_entries > $ids_limit)
+        my $num_entries = scalar( () = $feeds{'RSS'}->entries() );
+        if ( $num_entries > $ids_limit )
         {
             die "Assert failed. $num_entries rather than the $ids_limit limit.";
         }
     }
 
-    return
-    {
-        'recent_ids' => [reverse(@recent_ids)],
-        'feeds' =>
-        {
-            'Atom' => $feeds{"Atom"},
+    return {
+        'recent_ids' => [ reverse(@recent_ids) ],
+        'feeds'      => {
+            'Atom'  => $feeds{"Atom"},
             'rss20' => $feeds{"RSS"},
         },
     };
 }
 
 
-
-1; # End of XML::Grammar::Fortune::Synd
+1;    # End of XML::Grammar::Fortune::Synd
 
 __END__
 
@@ -310,7 +314,7 @@ XML-Grammar-Fortune files.
 
 =head1 VERSION
 
-version 0.0214
+version 0.0215
 
 =head1 SYNOPSIS
 
@@ -359,81 +363,20 @@ Returns:
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-xml-grammar-fortune-synd at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fortune-Synd>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc XML::Grammar::Fortune::Synd
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fortune-Synd>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/XML-Grammar-Fortune-Synd>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/XML-Grammar-Fortune-Synd>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/XML-Grammar-Fortune-Synd>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 Shlomi Fish, all rights reserved.
 
-This program is released under the following license: MIT/X11 License
+This program is released under the following license: MIT/Expat License
 
 http://www.opensource.org/licenses/mit-license.php
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2019 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/fortune-xml/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc XML::Grammar::Fortune::Synd
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -451,14 +394,6 @@ L<https://metacpan.org/release/XML-Grammar-Fortune-Synd>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/XML-Grammar-Fortune-Synd>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -467,22 +402,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fortune-Synd>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fortune-Synd>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/XML-Grammar-Fortune-Synd>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -531,4 +450,25 @@ L<https://github.com/shlomif/fortune-xml>
 
   git clone git://github.com/shlomif/fortune-xml.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/fortune-xml/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
