@@ -1,5 +1,5 @@
 package XML::Grammar::Fortune::Synd::App;
-$XML::Grammar::Fortune::Synd::App::VERSION = '0.0214';
+$XML::Grammar::Fortune::Synd::App::VERSION = '0.0215';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use parent 'Exporter';
 
 use vars qw(@EXPORT);
 
-@EXPORT=('run');
+@EXPORT = ('run');
 
 use Getopt::Long;
 use File::Spec;
@@ -15,7 +15,6 @@ use File::Spec;
 use XML::Grammar::Fortune::Synd;
 
 
-
 sub run
 {
     my $dir;
@@ -29,20 +28,19 @@ sub run
     my $feed_author;
 
     GetOptions(
-        'dir=s' => \$dir,
-        'xml-file=s' => \@xml_files,
-        'yaml-data=s' => \$yaml_data_file,
+        'dir=s'         => \$dir,
+        'xml-file=s'    => \@xml_files,
+        'yaml-data=s'   => \$yaml_data_file,
         'atom-output=s' => \$atom_output_fn,
-        'rss-output=s' => \$rss_output_fn,
-        'master-url=s' => \$master_url,
-        'title=s' => \$feed_title,
-        'tagline=s' => \$feed_tagline,
-        'author=s' => \$feed_author,
+        'rss-output=s'  => \$rss_output_fn,
+        'master-url=s'  => \$master_url,
+        'title=s'       => \$feed_title,
+        'tagline=s'     => \$feed_tagline,
+        'author=s'      => \$feed_author,
     );
 
-
     my $url_callback = sub {
-        my ($self, $args) = @_;
+        my ( $self, $args ) = @_;
 
         my $id_obj = $args->{id_obj};
 
@@ -55,7 +53,7 @@ sub run
 
     my $syndicator = XML::Grammar::Fortune::Synd->new(
         {
-            xml_files => \@xml_files,
+            xml_files    => \@xml_files,
             url_callback => $url_callback,
         }
     );
@@ -64,40 +62,40 @@ sub run
 
     if ($atom_output_fn)
     {
-        my (undef, undef, $atom_base) = File::Spec->splitpath($atom_output_fn);
-        push @more_params, (atom_self_link => "$master_url$atom_base");
+        my ( undef, undef, $atom_base ) =
+            File::Spec->splitpath($atom_output_fn);
+        push @more_params, ( atom_self_link => "$master_url$atom_base" );
     }
 
     if ($rss_output_fn)
     {
-        my (undef, undef, $rss_base) = File::Spec->splitpath($rss_output_fn);
-        push @more_params, (rss_self_link => "$master_url$rss_base");
+        my ( undef, undef, $rss_base ) = File::Spec->splitpath($rss_output_fn);
+        push @more_params, ( rss_self_link => "$master_url$rss_base" );
     }
 
     my $recent_ids_struct = $syndicator->calc_feeds(
-           {
-                yaml_persistence_file => $yaml_data_file,
-                yaml_persistence_file_out => $yaml_data_file,
-                xmls_dir => $dir,
-                feed_params =>
-                {
-                    title => $feed_title,
-                    'link' => $master_url,
-                    tagline => $feed_tagline,
-                    author => $feed_author,
-                    @more_params,
-                },
-            }
-        );
+        {
+            yaml_persistence_file     => $yaml_data_file,
+            yaml_persistence_file_out => $yaml_data_file,
+            xmls_dir                  => $dir,
+            feed_params               => {
+                title   => $feed_title,
+                'link'  => $master_url,
+                tagline => $feed_tagline,
+                author  => $feed_author,
+                @more_params,
+            },
+        }
+    );
 
-    if (defined($atom_output_fn))
+    if ( defined($atom_output_fn) )
     {
         open my $atom_out, ">", $atom_output_fn;
         print {$atom_out} $recent_ids_struct->{'feeds'}->{'Atom'}->as_xml();
         close($atom_out);
     }
 
-    if (defined($rss_output_fn))
+    if ( defined($rss_output_fn) )
     {
         open my $rss20_out, ">", $rss_output_fn;
         print {$rss20_out} $recent_ids_struct->{'feeds'}->{'rss20'}->as_xml();
@@ -119,7 +117,7 @@ application to syndicate FortuneXML as Atom/RSS.
 
 =head1 VERSION
 
-version 0.0214
+version 0.0215
 
 =head1 SYNOPSIS
 
@@ -131,37 +129,10 @@ version 0.0214
 
 Call with no arguments to run the application from the commandline.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2019 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/fortune-xml/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc XML::Grammar::Fortune::Synd::App
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -179,14 +150,6 @@ L<https://metacpan.org/release/XML-Grammar-Fortune-Synd>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/XML-Grammar-Fortune-Synd>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -195,22 +158,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fortune-Synd>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fortune-Synd>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/XML-Grammar-Fortune-Synd>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -259,4 +206,25 @@ L<https://github.com/shlomif/fortune-xml>
 
   git clone git://github.com/shlomif/fortune-xml.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/fortune-xml/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
