@@ -12,24 +12,18 @@ our @EXPORT_OK = qw($temp_dir cur_fn fn yaml_fn atom_fn rss_fn common_fns dir);
 sub dir
 {
     my $fn = shift;
-    return File::Spec->catdir(
-        File::Spec->curdir(),
-        (split m!/!, $fn),
-    );
+    return File::Spec->catdir( File::Spec->curdir(), ( split m!/!, $fn ), );
 }
 
 sub cur_fn
 {
     my $fn = shift;
-    return File::Spec->catfile(
-        File::Spec->curdir(),
-        (split m!/!, $fn),
-    );
+    return File::Spec->catfile( File::Spec->curdir(), ( split m!/!, $fn ), );
 }
 
 sub fn
 {
-    return File::Spec->catfile($temp_dir, shift);
+    return File::Spec->catfile( $temp_dir, shift );
 }
 
 sub yaml_fn
@@ -49,11 +43,10 @@ sub rss_fn
 
 sub common_fns
 {
-    return
-    [
-        "--yaml-data" => yaml_fn(),
+    return [
+        "--yaml-data"   => yaml_fn(),
         "--atom-output" => atom_fn(),
-        "--rss-output" => rss_fn(),
+        "--rss-output"  => rss_fn(),
     ];
 }
 
